==> xmonad-extras-0.17.2-105-x86_64.pkg.tar.zst: usr/share/haskell/register/xmonad-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad-extras
version:              0.17.2
visibility:           public
id:                   xmonad-extras-0.17.2-Fx48P6lu6rUDNtxBF1ARGZ
key:                  xmonad-extras-0.17.2-Fx48P6lu6rUDNtxBF1ARGZ
license:              BSD-3-Clause
maintainer:
    Sibi Prabakaran<sibi@psibi.in>, daniel@wagner-home.com, daniel.schoepe@googlemail.com

author:               The Daniels Schoepe and Wagner
homepage:             https://github.com/xmonad/xmonad-extras
synopsis:             Third party extensions for xmonad with wacky dependencies
description:
    Various modules for xmonad that cannot be added to xmonad-contrib
    because of additional dependencies.

category:             System
abi:                  207e566751ffaf3bc5a30074f0a45e85
exposed:              True
exposed-modules:
    XMonad.Actions.Eval XMonad.Actions.Invert XMonad.Actions.Volume
    XMonad.Hooks.PerWindowKbdLayout XMonad.Prompt.Eval
    XMonad.Prompt.MPD XMonad.Util.Brightness
    XMonad.Util.WindowPropertiesRE

import-dirs:          /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad-extras
hs-libraries:         HSxmonad-extras-0.17.2-Fx48P6lu6rUDNtxBF1ARGZ
depends:
    X11-1.10.3-1fch9sEthm2E7hyJAmNZGG
    alsa-mixer-0.3.0.1-64d7bL5FCNwLOsX9HNe40u base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    dbus-1.3.2-DXzjdijrZ8R68xd5qiCL7W
    hint-0.9.0.8-uqmMKPjjdcKSsW9RZrgHr
    libmpd-0.10.0.1-6JopOcidu6PL49jBYhRwwj mtl-2.2.2
    network-3.1.4.0-F6j0uAI5udHBrXI4nYArv7
    regex-posix-0.96.0.2-AHNuIP1Pa8gKU2TxlSaYg9
    xmonad-0.18.0-3bwCbXYpFJs4V6DZvpT2eD
    xmonad-contrib-0.18.1-IrH8ZVAvFerHQotP1XAMJ

haddock-interfaces:   /usr/share/doc/xmonad-extras/html/xmonad-extras.haddock
haddock-html:         /usr/share/doc/xmonad-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> xmonad-extras-0.17.2-106-x86_64.pkg.tar.zst: usr/share/haskell/register/xmonad-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad-extras
version:              0.17.2
visibility:           public
id:                   xmonad-extras-0.17.2-IL0fp2e3N6AAjsCgy23LSr
key:                  xmonad-extras-0.17.2-IL0fp2e3N6AAjsCgy23LSr
license:              BSD-3-Clause
maintainer:
    Sibi Prabakaran<sibi@psibi.in>, daniel@wagner-home.com, daniel.schoepe@googlemail.com

author:               The Daniels Schoepe and Wagner
homepage:             https://github.com/xmonad/xmonad-extras
synopsis:             Third party extensions for xmonad with wacky dependencies
description:
    Various modules for xmonad that cannot be added to xmonad-contrib
    because of additional dependencies.

category:             System
abi:                  4f37fb5494eeb7dd694d4f08bbc89610
exposed:              True
exposed-modules:
    XMonad.Actions.Eval XMonad.Actions.Invert XMonad.Actions.Volume
    XMonad.Hooks.PerWindowKbdLayout XMonad.Prompt.Eval
    XMonad.Prompt.MPD XMonad.Util.Brightness
    XMonad.Util.WindowPropertiesRE

import-dirs:          /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad-extras
hs-libraries:         HSxmonad-extras-0.17.2-IL0fp2e3N6AAjsCgy23LSr
depends:
    X11-1.10.3-1fch9sEthm2E7hyJAmNZGG
    alsa-mixer-0.3.0.1-64d7bL5FCNwLOsX9HNe40u base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    dbus-1.3.2-GvWmcpfJCObCEpyom8PeSR
    hint-0.9.0.8-3KQlzZFtRn2DkIMuQ7SGcD
    libmpd-0.10.0.1-4o50NrTBmks4Cq8sEw5Rkm mtl-2.2.2
    network-3.1.4.0-KV3OkCyx0pcI1DdyD3ZbeB
    regex-posix-0.96.0.2-AHNuIP1Pa8gKU2TxlSaYg9
    xmonad-0.18.0-B8gJmgS4qdIFVxs3XGok8z
    xmonad-contrib-0.18.1-9F0o1OGTpqhAQYPJk5VM9C

haddock-interfaces:   /usr/share/doc/xmonad-extras/html/xmonad-extras.haddock
haddock-html:         /usr/share/doc/xmonad-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
